summaryrefslogtreecommitdiff
path: root/bus.h
diff options
context:
space:
mode:
Diffstat (limited to 'bus.h')
-rw-r--r--bus.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/bus.h b/bus.h
index cc469f56ce7..65458436bed 100644
--- a/bus.h
+++ b/bus.h
@@ -46,7 +46,7 @@
* @conn_rwlock: Read/Write lock for all lists of child connections
* @conn_hash: Map of connection IDs
* @monitors_list: Connections that monitor this bus
* @meta: Meta information about the bus creator
*
* A bus provides a "bus" endpoint node.
*
@@ -78,7 +78,7 @@ struct kdbus_bus {
DECLARE_HASHTABLE(conn_hash, 8);
struct list_head monitors_list;
- struct kdbus_meta *meta;
+ struct kdbus_meta_proc *creator_meta;
};
struct kdbus_kmsg;
@@ -46,7 +46,7 @@
* @conn_hash: Map of connection IDs
* @monitors_list: Connections that monitor this bus
- * @meta: Meta information about the bus creator
+ * @meta_proc: Meta information about the bus creator
*
* A bus provides a "bus" endpoint node.